@@ -1,7 +1,11 @@
 # The minor version corresponds to the Lambda layer version.
 # E.g.,, version 0.5.0 gets packaged into layer version 5.
-__version__ = "3.49.0"
+try:
+    import importlib.metadata as importlib_metadata
+except ModuleNotFoundError:
+    import importlib_metadata
 
+__version__ = importlib_metadata.version(__name__)
 
 import os
 import logging
